summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit94ec53c96c3d5dc4a427e7dc4bbaa863add5cfa4 (patch)
tree0425f63afbe46c26d58a6bbcf8a7e6d026a1bb7e
parentf899c4c05f6b7578b8317ae8a1f71801e8d4b5d0 (diff)
downloadkipi-plugins-94ec53c96c3d5dc4a427e7dc4bbaa863add5cfa4.tar.gz
kipi-plugins-94ec53c96c3d5dc4a427e7dc4bbaa863add5cfa4.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/libraries/kipi-plugins@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--kipi-plugins/batchprocessimages/batchprocessimagesdialog.cpp4
-rw-r--r--kipi-plugins/batchprocessimages/convertimagesdialog.cpp2
-rw-r--r--kipi-plugins/batchprocessimages/renameimageswidget.cpp8
-rw-r--r--kipi-plugins/batchprocessimages/resizeimagesdialog.cpp8
-rw-r--r--kipi-plugins/calendar/calformatter.cpp10
-rw-r--r--kipi-plugins/calendar/calsettings.cpp2
-rw-r--r--kipi-plugins/calendar/monthwidget.cpp2
-rw-r--r--kipi-plugins/cdarchiving/cdarchiving.cpp4
-rw-r--r--kipi-plugins/findimages/Doxyfile2
-rw-r--r--kipi-plugins/findimages/displaycompare.cpp2
-rw-r--r--kipi-plugins/findimages/fastcompare.cpp10
-rw-r--r--kipi-plugins/findimages/finddupplicatedialog.cpp8
-rw-r--r--kipi-plugins/findimages/finddupplicateimages.cpp2
-rw-r--r--kipi-plugins/findimages/fuzzycompare.cpp6
-rw-r--r--kipi-plugins/flickrexport/flickrtalker.cpp2
-rw-r--r--kipi-plugins/flickrexport/flickrwindow.cpp4
-rw-r--r--kipi-plugins/flickrexport/imageslist.cpp22
-rw-r--r--kipi-plugins/galleryexport/gallerytalker.cpp6
-rw-r--r--kipi-plugins/galleryexport/gallerywindow.cpp4
-rw-r--r--kipi-plugins/gpssync/kmlexport.cpp2
-rw-r--r--kipi-plugins/htmlexport/THEME_HOWTO4
-rw-r--r--kipi-plugins/htmlexport/generator.cpp8
-rw-r--r--kipi-plugins/htmlexport/theme.cpp2
-rw-r--r--kipi-plugins/imageviewer/texture.cpp2
-rw-r--r--kipi-plugins/imageviewer/viewerwidget.cpp4
-rw-r--r--kipi-plugins/jpeglossless/convert2grayscale.cpp2
-rw-r--r--kipi-plugins/jpeglossless/imageflip.cpp2
-rw-r--r--kipi-plugins/jpeglossless/imagerotate.cpp2
-rw-r--r--kipi-plugins/jpeglossless/utils.cpp4
-rw-r--r--kipi-plugins/kameraklient/cameraiconview.cpp6
-rw-r--r--kipi-plugins/kameraklient/cameralist.cpp2
-rw-r--r--kipi-plugins/kameraklient/cameralist.h2
-rw-r--r--kipi-plugins/kameraklient/cameraselection.cpp10
-rw-r--r--kipi-plugins/kameraklient/cameraui.cpp6
-rw-r--r--kipi-plugins/kameraklient/gpfileitemcontainer.cpp22
-rw-r--r--kipi-plugins/kameraklient/gpfileiteminfodlg.cpp6
-rw-r--r--kipi-plugins/kameraklient/setupcamera.cpp2
-rw-r--r--kipi-plugins/kameraklient/thumbview.cpp12
-rw-r--r--kipi-plugins/metadataedit/exifeditdialog.cpp2
-rw-r--r--kipi-plugins/metadataedit/iptceditdialog.cpp2
-rw-r--r--kipi-plugins/mpegencoder/checkbinprog.cpp18
-rwxr-xr-xkipi-plugins/mpegencoder/images2mpg22
-rw-r--r--kipi-plugins/mpegencoder/kimg2mpg.cpp22
-rw-r--r--kipi-plugins/picasawebexport/picasawebtalker.cpp6
-rw-r--r--kipi-plugins/printwizard/frmprintwizard.cpp20
-rw-r--r--kipi-plugins/printwizard/tphoto.cpp2
-rw-r--r--kipi-plugins/rawconverter/batchdialog.cpp6
-rw-r--r--kipi-plugins/rawconverter/iccjpeg.c2
-rw-r--r--kipi-plugins/rawconverter/plugin_rawconverter.cpp2
-rw-r--r--kipi-plugins/rawconverter/rawdecodingiface.cpp4
-rw-r--r--kipi-plugins/sendimages/sendimages.cpp18
-rw-r--r--kipi-plugins/simpleviewerexport/simpleviewerexport.cpp18
-rw-r--r--kipi-plugins/slideshow/slideshowloader.cpp2
-rw-r--r--kipi-plugins/sync/gallerywindow.cpp4
-rw-r--r--kipi-plugins/sync/sinkfactory.cpp4
-rw-r--r--kipi-plugins/sync/sinks/gallery/gallerysink.cpp6
56 files changed, 184 insertions, 184 deletions
diff --git a/kipi-plugins/batchprocessimages/batchprocessimagesdialog.cpp b/kipi-plugins/batchprocessimages/batchprocessimagesdialog.cpp
index 43306e7..e47f85b 100644
--- a/kipi-plugins/batchprocessimages/batchprocessimagesdialog.cpp
+++ b/kipi-plugins/batchprocessimages/batchprocessimagesdialog.cpp
@@ -299,7 +299,7 @@ void BatchProcessImagesDialog::slotImagesFilesButtonRem( void )
{
m_listFiles->takeItem(pitem);
m_listFiles->setSelected( m_listFiles->currentItem(), true );
- m_selectedImageFiles.remove(m_selectedImageFiles.tqfind(pitem->pathSrc()));
+ m_selectedImageFiles.remove(m_selectedImageFiles.find(pitem->pathSrc()));
delete pitem;
m_nbItem = m_selectedImageFiles.count();
@@ -1062,7 +1062,7 @@ TQString BatchProcessImagesDialog::RenameTargetImageFile(TQFileInfo *fi)
{
++Enumerator;
Temp = Temp.setNum( Enumerator );
- NewDestUrl = fi->filePath().left( fi->filePath().tqfindRev('.', -1)) + "_" + Temp
+ NewDestUrl = fi->filePath().left( fi->filePath().findRev('.', -1)) + "_" + Temp
+ "." + fi->filePath().section('.', -1 );
}
while ( Enumerator < 100 &&
diff --git a/kipi-plugins/batchprocessimages/convertimagesdialog.cpp b/kipi-plugins/batchprocessimages/convertimagesdialog.cpp
index 73f6706..a4be7b6 100644
--- a/kipi-plugins/batchprocessimages/convertimagesdialog.cpp
+++ b/kipi-plugins/batchprocessimages/convertimagesdialog.cpp
@@ -357,7 +357,7 @@ TQString ConvertImagesDialog::oldFileName2NewFileName(TQString fileName)
{
TQString Temp;
- Temp = fileName.left( fileName.tqfindRev('.', -1) ); // The source file name without extension.
+ Temp = fileName.left( fileName.findRev('.', -1) ); // The source file name without extension.
Temp = Temp + "." + ImageFileExt(m_Type->currentText()); // Added new file extension.
return Temp;
diff --git a/kipi-plugins/batchprocessimages/renameimageswidget.cpp b/kipi-plugins/batchprocessimages/renameimageswidget.cpp
index eee59b1..630e4dd 100644
--- a/kipi-plugins/batchprocessimages/renameimageswidget.cpp
+++ b/kipi-plugins/batchprocessimages/renameimageswidget.cpp
@@ -349,9 +349,9 @@ TQString RenameImagesWidget::oldToNewName(BatchProcessImagesItem* item,
{
TQString format = m_formatDateEdit->text();
format = format.simplifyWhiteSpace();
- format.tqreplace("%%","%");
- format.tqreplace("%s","");
- format.tqreplace("/", "");
+ format.replace("%%","%");
+ format.replace("%s","");
+ format.replace("/", "");
time_t time = info.time().toTime_t();
struct tm* time_tm = ::localtime(&time);
@@ -522,7 +522,7 @@ void RenameImagesWidget::slotAddImages()
for (KURL::List::iterator it = urls.begin(); it != urls.end(); ++it)
{
- if (m_urlList.tqcontains(*it))
+ if (m_urlList.contains(*it))
continue;
new BatchProcessImagesItem(m_listView,
diff --git a/kipi-plugins/batchprocessimages/resizeimagesdialog.cpp b/kipi-plugins/batchprocessimages/resizeimagesdialog.cpp
index 132f528..6c2f16a 100644
--- a/kipi-plugins/batchprocessimages/resizeimagesdialog.cpp
+++ b/kipi-plugins/batchprocessimages/resizeimagesdialog.cpp
@@ -447,16 +447,16 @@ TQString ResizeImagesDialog::makeProcess(KProcess* proc, BatchProcessImagesItem
if (w < h) // (w < h) because all paper dimensions are vertically given !
{
- Temp = m_paperSize.left(m_paperSize.tqfind('x'));
+ Temp = m_paperSize.left(m_paperSize.find('x'));
m_xPixels = (int)( (float)(Temp.toInt() * Dpi) / (float)(2.54) );
- Temp = m_paperSize.right(m_paperSize.tqfind('x'));
+ Temp = m_paperSize.right(m_paperSize.find('x'));
m_yPixels = (int)( (float)(Temp.toInt() * Dpi) / (float)(2.54) );
}
else
{
- Temp = m_paperSize.left(m_paperSize.tqfind('x'));
+ Temp = m_paperSize.left(m_paperSize.find('x'));
m_yPixels = (int)( (float)(Temp.toInt() * Dpi) / (float)(2.54) );
- Temp = m_paperSize.right(m_paperSize.tqfind('x'));
+ Temp = m_paperSize.right(m_paperSize.find('x'));
m_xPixels = (int)( (float)(Temp.toInt() * Dpi) / (float)(2.54) );
}
}
diff --git a/kipi-plugins/calendar/calformatter.cpp b/kipi-plugins/calendar/calformatter.cpp
index b51d6fd..f0f8f4c 100644
--- a/kipi-plugins/calendar/calformatter.cpp
+++ b/kipi-plugins/calendar/calformatter.cpp
@@ -167,7 +167,7 @@ bool KIPICalendarPlugin::CalFormatter::isSpecial(int month, int day)
TQDate dt;
KGlobal::locale()->calendar()->setYMD(dt, year_, month, day);
- return (isPrayDay(month,day) || d->oh.tqcontains(dt) || d->fh.tqcontains(dt));
+ return (isPrayDay(month,day) || d->oh.contains(dt) || d->fh.contains(dt));
}
@@ -182,10 +182,10 @@ TQColor KIPICalendarPlugin::CalFormatter::getDayColor(int month, int day)
if (isPrayDay(month, day))
return TQt::red;
- if (d->oh.tqcontains(dt))
+ if (d->oh.contains(dt))
return TQt::red;
- if (d->fh.tqcontains(dt))
+ if (d->fh.contains(dt))
return TQt::green;
//default
@@ -203,10 +203,10 @@ TQString KIPICalendarPlugin::CalFormatter::getDayDescr(int month, int day)
TQString ret;
- if (d->oh.tqcontains(dt))
+ if (d->oh.contains(dt))
ret = d->oh[dt].description;
- if (d->fh.tqcontains(dt)) {
+ if (d->fh.contains(dt)) {
if (ret.isNull())
return d->fh[dt].description;
else
diff --git a/kipi-plugins/calendar/calsettings.cpp b/kipi-plugins/calendar/calsettings.cpp
index bf008c0..2c5f112 100644
--- a/kipi-plugins/calendar/calsettings.cpp
+++ b/kipi-plugins/calendar/calsettings.cpp
@@ -67,7 +67,7 @@ void CalSettings::setImage(int month, const KURL& path)
KURL CalSettings::getImage(int month) const
{
- return monthMap_.tqcontains(month) ? monthMap_[month] : KURL();
+ return monthMap_.contains(month) ? monthMap_[month] : KURL();
}
} // NameSpace KIPICalendarPlugin
diff --git a/kipi-plugins/calendar/monthwidget.cpp b/kipi-plugins/calendar/monthwidget.cpp
index 411affe..f93e5e4 100644
--- a/kipi-plugins/calendar/monthwidget.cpp
+++ b/kipi-plugins/calendar/monthwidget.cpp
@@ -172,7 +172,7 @@ void MonthWidget::slotGotThumbnaiL(const KFileItem* , const TQPixmap& pix)
void MonthWidget::mouseReleaseEvent(TQMouseEvent* e)
{
- if (!contentsRect().tqcontains(e->pos())) return;
+ if (!contentsRect().contains(e->pos())) return;
if (e->button() == Qt::LeftButton)
{
diff --git a/kipi-plugins/cdarchiving/cdarchiving.cpp b/kipi-plugins/cdarchiving/cdarchiving.cpp
index 346aa2e..aae1706 100644
--- a/kipi-plugins/cdarchiving/cdarchiving.cpp
+++ b/kipi-plugins/cdarchiving/cdarchiving.cpp
@@ -1912,7 +1912,7 @@ TQString CDArchiving::webifyFileName(TQString fileName)
fileName=fileName.lower();
// Remove potentially troublesome chars
- fileName=fileName.tqreplace(TQRegExp("[^-0-9a-zA-Z]+"), "_");
+ fileName=fileName.replace(TQRegExp("[^-0-9a-zA-Z]+"), "_");
return fileName;
}
@@ -1925,7 +1925,7 @@ TQString CDArchiving::makeFileNameUnique(TQStringList& list, TQString fileName)
// Make sure the file name is unique
TQString fileNameBase=fileName;
int count=1;
- while (list.tqfindIndex(fileName)!=-1)
+ while (list.findIndex(fileName)!=-1)
{
fileName=fileNameBase + "-" + TQString::number(count);
++count;
diff --git a/kipi-plugins/findimages/Doxyfile b/kipi-plugins/findimages/Doxyfile
index 8af60b1..339dc76 100644
--- a/kipi-plugins/findimages/Doxyfile
+++ b/kipi-plugins/findimages/Doxyfile
@@ -84,7 +84,7 @@ REPEAT_BRIEF = YES
# used as the annotated text. Otherwise, the brief description is used as-is.
# If left blank, the following values are used ("$name" is automatically
# replaced with the name of the entity): "The $name class" "The $name widget"
-# "The $name file" "is" "provides" "specifies" "tqcontains"
+# "The $name file" "is" "provides" "specifies" "contains"
# "represents" "a" "an" "the"
ABBREVIATE_BRIEF =
diff --git a/kipi-plugins/findimages/displaycompare.cpp b/kipi-plugins/findimages/displaycompare.cpp
index bd4b5f3..1f46888 100644
--- a/kipi-plugins/findimages/displaycompare.cpp
+++ b/kipi-plugins/findimages/displaycompare.cpp
@@ -344,7 +344,7 @@ void DisplayCompare::slotDisplayLeft(TQListViewItem * item)
KApplication::setOverrideCursor( waitCursor );
listEq->clear();
FindOriginalItem *pitem = static_cast<FindOriginalItem*>( item );
- TQPtrVector < TQFile > *list = (TQPtrVector < TQFile > *)m_cmp.tqfind(pitem->fullpath());
+ TQPtrVector < TQFile > *list = (TQPtrVector < TQFile > *)m_cmp.find(pitem->fullpath());
TQImage im(pitem->fullpath());
if ( !im.isNull() )
diff --git a/kipi-plugins/findimages/fastcompare.cpp b/kipi-plugins/findimages/fastcompare.cpp
index 0cd0b51..8b82877 100644
--- a/kipi-plugins/findimages/fastcompare.cpp
+++ b/kipi-plugins/findimages/fastcompare.cpp
@@ -67,7 +67,7 @@ TQDict < TQPtrVector < TQFile > > KIPIFindDupplicateImagesPlugin::FastCompare::c
size = TQString::number(TQFileInfo (*file).size ());
// if not in the table, we do it
- if ( !dict->tqfind (size) )
+ if ( !dict->find (size) )
{
list = new TQPtrVector < TQFile >;
list->setAutoDelete(true);
@@ -75,7 +75,7 @@ TQDict < TQPtrVector < TQFile > > KIPIFindDupplicateImagesPlugin::FastCompare::c
}
// Read the list
- list = (TQPtrVector < TQFile > *)dict->tqfind (size);
+ list = (TQPtrVector < TQFile > *)dict->find (size);
//Add the file
list->resize (list->size () + 1);
@@ -117,7 +117,7 @@ TQDict < TQPtrVector < TQFile > > KIPIFindDupplicateImagesPlugin::FastCompare::c
sendMessage( m_parent, KIPIFindDupplicateImagesPlugin::Exact,file1->name(),filesList.count() + count, true, false );
- if (!fait->tqfind (file1->name()))
+ if (!fait->find (file1->name()))
{
for (unsigned int j = i + 1; j < list->size (); j++)
{
@@ -131,14 +131,14 @@ TQDict < TQPtrVector < TQFile > > KIPIFindDupplicateImagesPlugin::FastCompare::c
// Add the file.
- if (!res.tqfind (file1->name ()))
+ if (!res.find (file1->name ()))
{
vect = new TQPtrVector < TQFile >;
vect->setAutoDelete(true);
res.insert (file1->name (), vect);
}
else
- vect = (TQPtrVector < TQFile > *)res.tqfind (file1->name ());
+ vect = (TQPtrVector < TQFile > *)res.find (file1->name ());
vect->resize (vect->size () + 1);
vect->insert (vect->size () - 1, file2);
diff --git a/kipi-plugins/findimages/finddupplicatedialog.cpp b/kipi-plugins/findimages/finddupplicatedialog.cpp
index 0ff548e..c1c0d76 100644
--- a/kipi-plugins/findimages/finddupplicatedialog.cpp
+++ b/kipi-plugins/findimages/finddupplicatedialog.cpp
@@ -167,7 +167,7 @@ void FindDuplicateDialog::setupPageMethod(void)
m_approximateThreshold = new KIntNumInput(88, groupBox1);
m_approximateThreshold->setRange(60, 100, 1, true );
TQWhatsThis::add( m_approximateThreshold, i18n("<p>Select here the approximate threshold "
- "value, as a percentage, for the 'Almost' tqfind-duplicates method. "
+ "value, as a percentage, for the 'Almost' find-duplicates method. "
"This value is used by the algorithm to distinguish two "
"similar images. The default value is 88.") );
vlay->addWidget( groupBox1 );
@@ -175,7 +175,7 @@ void FindDuplicateDialog::setupPageMethod(void)
//---------------------------------------------
TQGroupBox * groupBox2 = new TQGroupBox( 1, Qt::Horizontal, i18n("Cache Maintenance"), page_setupMethod );
- new TQLabel(i18n("The tqfind-duplicate-images process uses a cache folder for images' fingerprints\n"
+ new TQLabel(i18n("The find-duplicate-images process uses a cache folder for images' fingerprints\n"
"to speed up the analysis of items from Albums."), groupBox2);
TQPushButton* updateCache = new TQPushButton( groupBox2, "UpdateCache" );
@@ -239,7 +239,7 @@ void FindDuplicateDialog::slotUpdateCache(void)
for( TQValueList<KIPI::ImageCollection>::ConstIterator album = albumsList.begin() ;
album != albumsList.end() ; ++album )
{
- if ( !albumsListPath.tqcontains( (*album).path().path() ) )
+ if ( !albumsListPath.contains( (*album).path().path() ) )
albumsListPath.append( (*album).path().path() );
}
@@ -261,7 +261,7 @@ void FindDuplicateDialog::slotPurgeCache(void)
for( TQValueList<KIPI::ImageCollection>::ConstIterator album = albumsList.begin() ;
album != albumsList.end() ; ++album )
{
- if ( !albumsListPath.tqcontains( (*album).path().path() ) )
+ if ( !albumsListPath.contains( (*album).path().path() ) )
albumsListPath.append( (*album).path().path() );
}
diff --git a/kipi-plugins/findimages/finddupplicateimages.cpp b/kipi-plugins/findimages/finddupplicateimages.cpp
index de977ac..dac9d1b 100644
--- a/kipi-plugins/findimages/finddupplicateimages.cpp
+++ b/kipi-plugins/findimages/finddupplicateimages.cpp
@@ -192,7 +192,7 @@ void FindDuplicateImages::compareAlbums(void)
for( KURL::List::Iterator it2 = Files.begin(); it2 != Files.end(); ++it2 )
{
- if ( !filesList.tqcontains( (*it2).path() ) )
+ if ( !filesList.contains( (*it2).path() ) )
{
filesList.append( (*it2).path() ); // PENDING(blackie) handle remote URLS
}
diff --git a/kipi-plugins/findimages/fuzzycompare.cpp b/kipi-plugins/findimages/fuzzycompare.cpp
index d588298..f9f9d91 100644
--- a/kipi-plugins/findimages/fuzzycompare.cpp
+++ b/kipi-plugins/findimages/fuzzycompare.cpp
@@ -105,7 +105,7 @@ TQDict < TQPtrVector < TQFile > > KIPIFindDupplicateImagesPlugin::FuzzyCompare:
// Create the 'ImageSimilarityData' data for the first image.
ImageSimilarityData *i1 = list->at(i);
- if (i1 && !fait->tqfind(i1->filename))
+ if (i1 && !fait->find(i1->filename))
{
sendMessage( m_parent, KIPIFindDupplicateImagesPlugin::Similar, i1->filename, 0, true, false );
@@ -122,14 +122,14 @@ TQDict < TQPtrVector < TQFile > > KIPIFindDupplicateImagesPlugin::FuzzyCompare:
TQPtrVector < TQFile > *vect;
// Add file to the list.
- if (!res.tqfind (i1->filename))
+ if (!res.find (i1->filename))
{
vect = new TQPtrVector < TQFile >;
vect->setAutoDelete(true);
res.insert (i1->filename, vect);
}
else
- vect = (TQPtrVector < TQFile > *)res.tqfind(i1->filename);
+ vect = (TQPtrVector < TQFile > *)res.find(i1->filename);
vect->resize (vect->size () + 1);
vect->insert (vect->size () - 1, new TQFile(i2->filename));
diff --git a/kipi-plugins/flickrexport/flickrtalker.cpp b/kipi-plugins/flickrexport/flickrtalker.cpp
index c3b83a9..1f13257 100644
--- a/kipi-plugins/flickrexport/flickrtalker.cpp
+++ b/kipi-plugins/flickrexport/flickrtalker.cpp
@@ -389,7 +389,7 @@ bool FlickrTalker::addPhoto(const TQString& photoPath, const FPhotoInfo& info,
TQString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
#endif
TQFileInfo fileInfo(photoPath);
- if (rawFilesExt.upper().tqcontains(fileInfo.extension(false).upper()))
+ if (rawFilesExt.upper().contains(fileInfo.extension(false).upper()))
KDcrawIface::KDcraw::loadDcrawPreview(image, photoPath);
else
image.load(photoPath);
diff --git a/kipi-plugins/flickrexport/flickrwindow.cpp b/kipi-plugins/flickrexport/flickrwindow.cpp
index a619157..609a5cd 100644
--- a/kipi-plugins/flickrexport/flickrwindow.cpp
+++ b/kipi-plugins/flickrexport/flickrwindow.cpp
@@ -352,7 +352,7 @@ void FlickrWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
}
else
{
- TQListViewItem* tqparent = m_albumDict.tqfind( album.parent_ref_num );
+ TQListViewItem* tqparent = m_albumDict.find( album.parent_ref_num );
if ( tqparent )
{
GAlbumViewItem* item = new GAlbumViewItem( tqparent, album.name,
@@ -383,7 +383,7 @@ void FlickrWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
if (lastSelectedID > 0)
{
- GAlbumViewItem* lastSelectedItem = m_albumDict.tqfind( lastSelectedID );
+ GAlbumViewItem* lastSelectedItem = m_albumDict.find( lastSelectedID );
if (lastSelectedItem)
{
m_tagView->setSelected( lastSelectedItem, true );
diff --git a/kipi-plugins/flickrexport/imageslist.cpp b/kipi-plugins/flickrexport/imageslist.cpp
index b93cc43..bb402a0 100644
--- a/kipi-plugins/flickrexport/imageslist.cpp
+++ b/kipi-plugins/flickrexport/imageslist.cpp
@@ -226,7 +226,7 @@ void ImagesList::slotAddImages(const KURL::List& list)
// Check if the new item already exist in the list.
- bool tqfind = false;
+ bool find = false;
TQListViewItemIterator it(d->listView);
while (it.current())
@@ -234,12 +234,12 @@ void ImagesList::slotAddImages(const KURL::List& list)
ImagesListViewItem* item = dynamic_cast<ImagesListViewItem*>(*it);
if (item->url() == imageUrl)
- tqfind = true;
+ find = true;
++it;
}
- if (!tqfind)
+ if (!find)
{
new ImagesListViewItem(d->listView, imageUrl);
urls.append(imageUrl);
@@ -280,10 +280,10 @@ void ImagesList::slotAddItems()
void ImagesList::slotRemoveItems()
{
- bool tqfind;
+ bool find;
do
{
- tqfind = false;
+ find = false;
TQListViewItemIterator it(d->listView);
while (it.current())
{
@@ -291,23 +291,23 @@ void ImagesList::slotRemoveItems()
if (item->isSelected())
{
delete item;
- tqfind = true;
+ find = true;
break;
}
++it;
}
}
- while(tqfind);
+ while(find);
emit signalImageListChanged(imageUrls().isEmpty());
}
void ImagesList::removeItemByUrl(const KURL& url)
{
- bool tqfind;
+ bool find;
do
{
- tqfind = false;
+ find = false;
TQListViewItemIterator it(d->listView);
while (it.current())
{
@@ -315,13 +315,13 @@ void ImagesList::removeItemByUrl(const KURL& url)
if (item->url() == url)
{
delete item;
- tqfind = true;
+ find = true;
break;
}
++it;
}
}
- while(tqfind);
+ while(find);
emit signalImageListChanged(imageUrls().isEmpty());
}
diff --git a/kipi-plugins/galleryexport/gallerytalker.cpp b/kipi-plugins/galleryexport/gallerytalker.cpp
index 4b2fda8..8a36c19 100644
--- a/kipi-plugins/galleryexport/gallerytalker.cpp
+++ b/kipi-plugins/galleryexport/gallerytalker.cpp
@@ -509,9 +509,9 @@ void GalleryTalker::parseResponseListPhotos(const TQByteArray &data)
}
else
{
- // Boris the Gallery default URL tqcontains "=" char. So we will split the string only from the first "=" char
+ // Boris the Gallery default URL contains "=" char. So we will split the string only from the first "=" char
TQStringList strlist = TQStringList();
- strlist << line.left(line.tqfind('=')) << line.mid(line.tqfind('=')+1);
+ strlist << line.left(line.find('=')) << line.mid(line.find('=')+1);
if (strlist.count() >= 2)
{
TQString key = strlist[0];
@@ -540,7 +540,7 @@ void GalleryTalker::parseResponseListPhotos(const TQByteArray &data)
}
else if (key.startsWith("baseurl"))
{
- albumURL = value.tqreplace("\\","");
+ albumURL = value.replace("\\","");
}
}
}
diff --git a/kipi-plugins/galleryexport/gallerywindow.cpp b/kipi-plugins/galleryexport/gallerywindow.cpp
index 8d17753..ea6a4b0 100644
--- a/kipi-plugins/galleryexport/gallerywindow.cpp
+++ b/kipi-plugins/galleryexport/gallerywindow.cpp
@@ -300,7 +300,7 @@ void GalleryWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
}
else
{
- TQListViewItem* tqparent = m_albumDict.tqfind( album.parent_ref_num );
+ TQListViewItem* tqparent = m_albumDict.find( album.parent_ref_num );
if ( tqparent )
{
GAlbumViewItem* item = new GAlbumViewItem( tqparent, album.title,
@@ -331,7 +331,7 @@ void GalleryWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
if (lastSelectedID > 0)
{
- GAlbumViewItem* lastSelectedItem = m_albumDict.tqfind( lastSelectedID );
+ GAlbumViewItem* lastSelectedItem = m_albumDict.find( lastSelectedID );
if (lastSelectedItem)
{
m_albumView->setSelected( lastSelectedItem, true );
diff --git a/kipi-plugins/gpssync/kmlexport.cpp b/kipi-plugins/gpssync/kmlexport.cpp
index 096ba97..e166191 100644
--- a/kipi-plugins/gpssync/kmlexport.cpp
+++ b/kipi-plugins/gpssync/kmlexport.cpp
@@ -94,7 +94,7 @@ TQString kmlExport::webifyFileName(const TQString &fileName)
TQString webFileName=fileName.lower();
// Remove potentially troublesome chars
- webFileName=webFileName.tqreplace(TQRegExp("[^-0-9a-z]+"), "_");
+ webFileName=webFileName.replace(TQRegExp("[^-0-9a-z]+"), "_");
return webFileName;
}
diff --git a/kipi-plugins/htmlexport/THEME_HOWTO b/kipi-plugins/htmlexport/THEME_HOWTO
index b217e7e..689b9e5 100644
--- a/kipi-plugins/htmlexport/THEME_HOWTO
+++ b/kipi-plugins/htmlexport/THEME_HOWTO
@@ -39,7 +39,7 @@ It's a .ini-style file and looks like this:
Url=http://example.com/themes/helloworld
We use a desktop file format so that entries can be translated. If you look at
-the desktop file for one of the themes shipped with the plugin, you will tqfind
+the desktop file for one of the themes shipped with the plugin, you will find
something like this:
[Desktop Entry]
@@ -78,7 +78,7 @@ Rename the desktop file accordingly:
cd snow2
mv snow.desktop snow2.desktop
-Edit "snow2.desktop": Remove all the `Name[...]` entries and tqreplace `Name=Snow`
+Edit "snow2.desktop": Remove all the `Name[...]` entries and replace `Name=Snow`
with `Name=Snow 2`.
You are done, you can now open your favorite KIPI enabled application and start the
diff --git a/kipi-plugins/htmlexport/generator.cpp b/kipi-plugins/htmlexport/generator.cpp
index 4844aa7..2e52161 100644
--- a/kipi-plugins/htmlexport/generator.cpp
+++ b/kipi-plugins/htmlexport/generator.cpp
@@ -66,7 +66,7 @@ TQString webifyFileName(TQString fileName) {
fileName=fileName.lower();
// Remove potentially troublesome chars
- fileName=fileName.tqreplace(TQRegExp("[^-0-9a-z]+"), "_");
+ fileName=fileName.replace(TQRegExp("[^-0-9a-z]+"), "_");
return fileName;
}
@@ -80,7 +80,7 @@ public:
TQString makeNameUnique(TQString name) {
TQString nameBase = name;
int count=2;
- while (mList.tqfindIndex(name)!=-1) {
+ while (mList.findIndex(name)!=-1) {
name = nameBase + TQString::number(count);
++count;
};
@@ -106,11 +106,11 @@ TQCString makeXsltParam(const TQString& txt) {
static const char apos='\'';
static const char quote='"';
- if (txt.tqfind(apos)==-1) {
+ if (txt.find(apos)==-1) {
// First or second case: no apos
param= apos + txt + apos;
- } else if (txt.tqfind(quote)==-1) {
+ } else if (txt.find(quote)==-1) {
// Third case: only apos, no quote
param= quote + txt + quote;
diff --git a/kipi-plugins/htmlexport/theme.cpp b/kipi-plugins/htmlexport/theme.cpp
index ebb4d97..02531a8 100644
--- a/kipi-plugins/htmlexport/theme.cpp
+++ b/kipi-plugins/htmlexport/theme.cpp
@@ -146,7 +146,7 @@ const Theme::List& Theme::getList() {
Theme* theme=new Theme;
theme->d->init(*it);
TQString internalName = theme->internalName();
- if (!internalNameList.tqcontains(internalName)) {
+ if (!internalNameList.contains(internalName)) {
sList << Theme::Ptr(theme);
internalNameList << internalName;
}
diff --git a/kipi-plugins/imageviewer/texture.cpp b/kipi-plugins/imageviewer/texture.cpp
index 065578c..ef8ba0b 100644
--- a/kipi-plugins/imageviewer/texture.cpp
+++ b/kipi-plugins/imageviewer/texture.cpp
@@ -106,7 +106,7 @@ bool Texture::load(TQString fn, TQSize size, GLuint tn)
TQString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
#endif
TQFileInfo fileInfo(fn);
- if (rawFilesExt.upper().tqcontains( fileInfo.extension(false).upper() )) {
+ if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() )) {
// it's a RAW file, use the libkdcraw loader
KDcrawIface::KDcraw::loadDcrawPreview(qimage, fn);
} else {
diff --git a/kipi-plugins/imageviewer/viewerwidget.cpp b/kipi-plugins/imageviewer/viewerwidget.cpp
index b0e51c8..dd8ef65 100644
--- a/kipi-plugins/imageviewer/viewerwidget.cpp
+++ b/kipi-plugins/imageviewer/viewerwidget.cpp
@@ -85,7 +85,7 @@ ViewerWidget::ViewerWidget(KIPI::Interface* i) {
// only add images to files
KMimeType::Ptr type = KMimeType::findByURL(s);
- bool isImage=type->name().tqfind("image")>=0;
+ bool isImage=type->name().find("image")>=0;
if ( isImage ) {
files.append(s);
@@ -681,7 +681,7 @@ OGLstate ViewerWidget::getOGLstate()
//GL_ARB_texture_rectangle is not supported
TQString s = TQString ( ( char* ) glGetString ( GL_EXTENSIONS ) );
- if ( !s.tqcontains ( "GL_ARB_texture_rectangle",false ) ) {
+ if ( !s.contains ( "GL_ARB_texture_rectangle",false ) ) {
return oglNoRectangularTexture;
}
diff --git a/kipi-plugins/jpeglossless/convert2grayscale.cpp b/kipi-plugins/jpeglossless/convert2grayscale.cpp
index 4c865c1..95aff08 100644
--- a/kipi-plugins/jpeglossless/convert2grayscale.cpp
+++ b/kipi-plugins/jpeglossless/convert2grayscale.cpp
@@ -258,7 +258,7 @@ bool ImageGrayScale::image2GrayScaleImageMagick(const TQString& src, const TQStr
}
// Processing error !
- err = i18n("Cannot convert to gray scale: %1").tqarg(m_stdErr.tqreplace('\n', ' '));
+ err = i18n("Cannot convert to gray scale: %1").tqarg(m_stdErr.replace('\n', ' '));
return false;
}
diff --git a/kipi-plugins/jpeglossless/imageflip.cpp b/kipi-plugins/jpeglossless/imageflip.cpp
index b3a2e9b..5cadb2f 100644
--- a/kipi-plugins/jpeglossless/imageflip.cpp
+++ b/kipi-plugins/jpeglossless/imageflip.cpp
@@ -213,7 +213,7 @@ bool ImageFlip::flipImageMagick(const TQString& src, const TQString& dest, FlipA
}
// Processing error !
- err = i18n("Cannot flip: %1").tqarg(m_stdErr.tqreplace('\n', ' '));
+ err = i18n("Cannot flip: %1").tqarg(m_stdErr.replace('\n', ' '));
return false;
}
diff --git a/kipi-plugins/jpeglossless/imagerotate.cpp b/kipi-plugins/jpeglossless/imagerotate.cpp
index 3115c16..31360ba 100644
--- a/kipi-plugins/jpeglossless/imagerotate.cpp
+++ b/kipi-plugins/jpeglossless/imagerotate.cpp
@@ -237,7 +237,7 @@ bool ImageRotate::rotateImageMagick(const TQString& src, const TQString& dest,
}
// Processing error !
- err = i18n("Cannot rotate: %1").tqarg(m_stdErr.tqreplace('\n', ' '));
+ err = i18n("Cannot rotate: %1").tqarg(m_stdErr.replace('\n', ' '));
return false;
}
diff --git a/kipi-plugins/jpeglossless/utils.cpp b/kipi-plugins/jpeglossless/utils.cpp
index d7b5b1a..9f5f0f4 100644
--- a/kipi-plugins/jpeglossless/utils.cpp
+++ b/kipi-plugins/jpeglossless/utils.cpp
@@ -175,7 +175,7 @@ bool Utils::updateMetadataImageMagick(const TQString& src, TQString& err)
}
// Processing error !
- err = i18n("Cannot update metadata: %1").tqarg(m_stdErr.tqreplace('\n', ' '));
+ err = i18n("Cannot update metadata: %1").tqarg(m_stdErr.replace('\n', ' '));
return false;
}
@@ -199,7 +199,7 @@ bool Utils::isRAW(const TQString& file)
#endif
TQFileInfo fileInfo(file);
- if (rawFilesExt.upper().tqcontains( fileInfo.extension(false).upper() ))
+ if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() ))
return true;
return false;
diff --git a/kipi-plugins/kameraklient/cameraiconview.cpp b/kipi-plugins/kameraklient/cameraiconview.cpp
index 5cc6fa5..6cf6f70 100644
--- a/kipi-plugins/kameraklient/cameraiconview.cpp
+++ b/kipi-plugins/kameraklient/cameraiconview.cpp
@@ -105,11 +105,11 @@ void CameraIconView::createPixmap(TQPixmap& pix, const TQString& icon, double sc
CameraIconItem* CameraIconView::addItem(const GPFileItemInfo* fileInfo) {
TQPixmap& pix = d->unknownPix;
- if(fileInfo->mime.tqcontains("image")) {
+ if(fileInfo->mime.contains("image")) {
pix = d->imagePix;
- } else if(fileInfo->mime.tqcontains("audio")) {
+ } else if(fileInfo->mime.contains("audio")) {
pix = d->audioPix;
- } else if(fileInfo->mime.tqcontains("video")) {
+ } else if(fileInfo->mime.contains("video")) {
pix = d->videoPix;
} else {
pix = d->unknownPix;
diff --git a/kipi-plugins/kameraklient/cameralist.cpp b/kipi-plugins/kameraklient/cameralist.cpp
index 5110c9a..46897eb 100644
--- a/kipi-plugins/kameraklient/cameralist.cpp
+++ b/kipi-plugins/kameraklient/cameralist.cpp
@@ -150,7 +150,7 @@ TQPtrList<CameraType>* CameraList::cameraList() {
return &d->clist;
}
-CameraType* CameraList::tqfind(const TQString& model) {
+CameraType* CameraList::find(const TQString& model) {
for (CameraType *ctype = d->clist.first(); ctype; ctype = d->clist.next()) {
if (ctype->model() == model) {
return ctype;
diff --git a/kipi-plugins/kameraklient/cameralist.h b/kipi-plugins/kameraklient/cameralist.h
index 264a579..4b624a3 100644
--- a/kipi-plugins/kameraklient/cameralist.h
+++ b/kipi-plugins/kameraklient/cameralist.h
@@ -44,7 +44,7 @@ class CameraList : public TQObject {
bool close();
void insert(CameraType* ctype);
void remove(CameraType* ctype);
- CameraType* tqfind(const TQString& title);
+ CameraType* find(const TQString& title);
void clear();
TQPtrList<CameraType>* cameraList();
static CameraList* instance();
diff --git a/kipi-plugins/kameraklient/cameraselection.cpp b/kipi-plugins/kameraklient/cameraselection.cpp
index 85bd040..183ddb9 100644
--- a/kipi-plugins/kameraklient/cameraselection.cpp
+++ b/kipi-plugins/kameraklient/cameraselection.cpp
@@ -160,16 +160,16 @@ void CameraSelection::slotHelp()
void CameraSelection::setCamera(const TQString& model, const TQString& port) {
TQString camModel(model);
- TQListViewItem* item = listView_->tqfindItem(camModel, 0);
+ TQListViewItem* item = listView_->findItem(camModel, 0);
if (!item) {
return;
}
listView_->setSelected(item, true);
listView_->ensureItemVisible(item);
- if (port.tqcontains("usb")) {
+ if (port.contains("usb")) {
usbButton_->setChecked(true);
- } else if (port.tqcontains("serial")) {
+ } else if (port.contains("serial")) {
serialButton_->setChecked(true);
for (int i=0; i<portPathComboBox_->count(); i++) {
if (port == portPathComboBox_->text(i)) {
@@ -209,7 +209,7 @@ void CameraSelection::slotSelectionChanged(TQListViewItem *item) {
TQString model(item->text(0));
TQStringList plist;
GPIface::getCameraSupportedPorts(model, plist);
- if (plist.tqcontains("serial")) {
+ if (plist.contains("serial")) {
serialButton_->setEnabled(true);
serialButton_->setChecked(true);
} else {
@@ -217,7 +217,7 @@ void CameraSelection::slotSelectionChanged(TQListViewItem *item) {
serialButton_->setChecked(false);
serialButton_->setEnabled(false);
}
- if (plist.tqcontains("usb")) {
+ if (plist.contains("usb")) {
usbButton_->setEnabled(true);
usbButton_->setChecked(true);
} else {
diff --git a/kipi-plugins/kameraklient/cameraui.cpp b/kipi-plugins/kameraklient/cameraui.cpp
index ab9d4bf..c936800 100644
--- a/kipi-plugins/kameraklient/cameraui.cpp
+++ b/kipi-plugins/kameraklient/cameraui.cpp
@@ -360,7 +360,7 @@ void CameraUI::cameraNewItems(const TQString& folder, const GPFileItemInfoList&
container_->addFiles(folder, infoList);
GPFileItemInfoList::const_iterator it;
for (it = infoList.begin(); it != infoList.end(); ++it) {
- if ((*it).mime.tqcontains("image")) {
+ if ((*it).mime.contains("image")) {
controller_->requestGetThumbnail(folder, (*it).name);
}
}
@@ -378,7 +378,7 @@ void CameraUI::cameraNewItems(const GPFileItemInfoList& infoList) {
container_->addFiles(infoList);
GPFileItemInfoList::const_iterator it;
for (it = infoList.begin(); it != infoList.end(); ++it) {
- if ((*it).mime.tqcontains("image")) {
+ if ((*it).mime.contains("image")) {
controller_->requestGetThumbnail((*it).folder, (*it).name);
}
}
@@ -413,7 +413,7 @@ void CameraUI::slotCameraConnectToggle() {
KMessageBox::error(this, i18n("There is no configured camera!"));
return;
}
- mCameraType = mCameraList->tqfind(mCameraComboBox->currentText());
+ mCameraType = mCameraList->find(mCameraComboBox->currentText());
setCameraType(*mCameraType);
setCameraConnected(false);
if(!cameraConnected_) {
diff --git a/kipi-plugins/kameraklient/gpfileitemcontainer.cpp b/kipi-plugins/kameraklient/gpfileitemcontainer.cpp
index 18c354c..1fd3cf3 100644
--- a/kipi-plugins/kameraklient/gpfileitemcontainer.cpp
+++ b/kipi-plugins/kameraklient/gpfileitemcontainer.cpp
@@ -64,7 +64,7 @@ void GPFileItemContainer::addFolder(const TQString& folder, const TQString& subf
}
path += subfolder;
kdDebug() << "GPFileItemContainer: Adding folder " << path << endl;
- if (!folderDict_.tqfind(path)) {
+ if (!folderDict_.find(path)) {
GPFolder *item = new GPFolder;
folderDict_.insert(path, item);
item->viewItem = folderView_->addFolder(folder, subfolder);
@@ -75,7 +75,7 @@ void GPFileItemContainer::addFolder(const TQString& folder, const TQString& subf
}
void GPFileItemContainer::addFiles(const TQString& folder, const GPFileItemInfoList& infoList) {
- GPFolder *folderItem = folderDict_.tqfind(folder);
+ GPFolder *folderItem = folderDict_.find(folder);
if (!folderItem) {
kdWarning() << "GPFileItemContainer: " << "Couldn't find Folder in Dict: " << folder << endl;
return;
@@ -83,7 +83,7 @@ void GPFileItemContainer::addFiles(const TQString& folder, const GPFileItemInfoL
GPFileDict* fileDict = folderItem->fileDict;
GPFileItemInfoList::const_iterator it;
for (it = infoList.begin(); it != infoList.end(); ++it) {
- GPFileItemInfo *fileInfo = fileDict->tqfind((*it).name);
+ GPFileItemInfo *fileInfo = fileDict->find((*it).name);
if (!fileInfo) {
// Hmm... Totally New file
fileInfo = new GPFileItemInfo((*it));
@@ -113,13 +113,13 @@ void GPFileItemContainer::addFiles(const GPFileItemInfoList& infoList) {
for (it = infoList.begin(); it != infoList.end(); ++it) {
GPFileItemInfo info(*it);
- GPFolder *folderItem = folderDict_.tqfind(info.folder);
+ GPFolder *folderItem = folderDict_.find(info.folder);
if (!folderItem) {
kdWarning() << "GPFileItemContainer: " << "Couldn't find Folder in Dict: " << info.folder << endl;
continue;
}
GPFileDict* fileDict = folderItem->fileDict;
- GPFileItemInfo *fileInfo = fileDict->tqfind((*it).name);
+ GPFileItemInfo *fileInfo = fileDict->find((*it).name);
if (!fileInfo) {
// Hmm... Totally New file
fileInfo = new GPFileItemInfo(info);
@@ -139,13 +139,13 @@ void GPFileItemContainer::addFiles(const GPFileItemInfoList& infoList) {
}
void GPFileItemContainer::addFile(const TQString& folder, const GPFileItemInfo& info) {
- GPFolder *folderItem = folderDict_.tqfind(folder);
+ GPFolder *folderItem = folderDict_.find(folder);
if (!folderItem) {
kdWarning() << "GPFileItemContainer: " << "Couldn't find Folder in Dict: " << folder << endl;
return;
}
GPFileDict* fileDict = folderItem->fileDict;
- GPFileItemInfo *fileInfo = fileDict->tqfind(info.name);
+ GPFileItemInfo *fileInfo = fileDict->find(info.name);
if (!fileInfo) {
// Hmm... Totally New file
fileInfo = new GPFileItemInfo(info);
@@ -166,13 +166,13 @@ void GPFileItemContainer::addFile(const TQString& folder, const GPFileItemInfo&
}
void GPFileItemContainer::delFile(const TQString& folder, const TQString& name) {
- GPFolder *folderItem = folderDict_.tqfind(folder);
+ GPFolder *folderItem = folderDict_.find(folder);
if (!folderItem) {
kdWarning() << "GPFileItemContainer: " << "Couldn't find Folder in Dict: " << folder << endl;
return;
}
GPFileDict* fileDict = folderItem->fileDict;
- GPFileItemInfo* fileInfo = fileDict->tqfind(name);
+ GPFileItemInfo* fileInfo = fileDict->find(name);
if (!fileInfo) {
kdWarning() << "GPFileItemContainer: " << "Couldn't File Item to Delete in Dict: " << name << endl;
return;
@@ -193,13 +193,13 @@ void GPFileItemContainer::delFile(const TQString& folder, const TQString& name)
}
CameraIconItem* GPFileItemContainer::findItem(const TQString& folder, const TQString& name) {
- GPFolder *folderItem = folderDict_.tqfind(folder);
+ GPFolder *folderItem = folderDict_.find(folder);
if (!folderItem) {
kdWarning() << "GPFileItemContainer: " << "Couldn't find Folder in Dict: " << folder << endl;
return 0;
}
GPFileDict* fileDict = folderItem->fileDict;
- GPFileItemInfo* fileInfo = fileDict->tqfind(name);
+ GPFileItemInfo* fileInfo = fileDict->find(name);
if (!fileInfo) {
kdWarning() << "GPFileItemContainer: " << "Couldn't File Item to Delete in Dict: " << name << endl;
return 0;
diff --git a/kipi-plugins/kameraklient/gpfileiteminfodlg.cpp b/kipi-plugins/kameraklient/gpfileiteminfodlg.cpp
index a97c7db..145e825 100644
--- a/kipi-plugins/kameraklient/gpfileiteminfodlg.cpp
+++ b/kipi-plugins/kameraklient/gpfileiteminfodlg.cpp
@@ -55,11 +55,11 @@ GPFileItemInfoDlg::GPFileItemInfoDlg(const GPFileItemInfo& info,
thumbLabel->setMargin(2);
thumbLabel->setPaletteBackgroundColor(tqcolorGroup().base());
if (!pixmap) {
- if (info.mime.tqcontains("image"))
+ if (info.mime.contains("image"))
thumbLabel->setPixmap(DesktopIcon("image"));
- else if (info.mime.tqcontains("audio"))
+ else if (info.mime.contains("audio"))
thumbLabel->setPixmap(DesktopIcon("audio"));
- else if (info.mime.tqcontains("video"))
+ else if (info.mime.contains("video"))
thumbLabel->setPixmap(DesktopIcon("video"));
else
thumbLabel->setPixmap(DesktopIcon("document"));
diff --git a/kipi-plugins/kameraklient/setupcamera.cpp b/kipi-plugins/kameraklient/setupcamera.cpp
index c772e4a..4ad2cc3 100644
--- a/kipi-plugins/kameraklient/setupcamera.cpp
+++ b/kipi-plugins/kameraklient/setupcamera.cpp
@@ -197,7 +197,7 @@ void SetupCamera::slotAutoDetectCamera() {
bool found = false;
CameraList* clist = CameraList::instance();
if (clist) {
- if (clist->tqfind(model)) {
+ if (clist->find(model)) {
found = true;
}
}
diff --git a/kipi-plugins/kameraklient/thumbview.cpp b/kipi-plugins/kameraklient/thumbview.cpp
index 09f5715..361a9b0 100644
--- a/kipi-plugins/kameraklient/thumbview.cpp
+++ b/kipi-plugins/kameraklient/thumbview.cpp
@@ -614,7 +614,7 @@ void ThumbView::rebuildContainers() {
appendContainer();
ThumbViewPrivate::ItemContainer* c = d->lastContainer;
while (item) {
- if (c->rect.tqcontains(item->rect())) {
+ if (c->rect.contains(item->rect())) {
c->items.append(item);
item = item->next;
} else if (c->rect.intersects(item->rect())) {
@@ -676,10 +676,10 @@ void ThumbView::updateItemContainer(ThumbItem *item) {
c = d->firstContainer;
}
const TQRect ir = item->rect();
- bool tqcontains = false;
+ bool contains = false;
for (;;) {
if (c->rect.intersects(ir)) {
- tqcontains = c->rect.tqcontains(ir);
+ contains = c->rect.contains(ir);
break;
}
c = c->next;
@@ -692,7 +692,7 @@ void ThumbView::updateItemContainer(ThumbItem *item) {
return;
}
c->items.append(item);
- if (!tqcontains) {
+ if (!contains) {
c = c->next;
if (!c) {
appendContainer();
@@ -711,10 +711,10 @@ ThumbItem* ThumbView::findItem(const TQPoint& pos) {
}
ThumbViewPrivate::ItemContainer *c = d->lastContainer;
for (; c; c = c->prev) {
- if ( c->rect.tqcontains(pos) ) {
+ if ( c->rect.contains(pos) ) {
ThumbItem *item = c->items.last();
for ( ; item; item = c->items.prev()) {
- if (item->rect().tqcontains( pos )) {
+ if (item->rect().contains( pos )) {
return item;
}
}
diff --git a/kipi-plugins/metadataedit/exifeditdialog.cpp b/kipi-plugins/metadataedit/exifeditdialog.cpp
index e802a3d..60258cb 100644
--- a/kipi-plugins/metadataedit/exifeditdialog.cpp
+++ b/kipi-plugins/metadataedit/exifeditdialog.cpp
@@ -278,7 +278,7 @@ void EXIFEditDialog::slotItemChanged()
setCaption(TQString("%1 (%2/%3) - %4")
.tqarg((*d->currItem).filename())
- .tqarg(d->urls.tqfindIndex(*(d->currItem))+1)
+ .tqarg(d->urls.findIndex(*(d->currItem))+1)
.tqarg(d->urls.count())
.tqarg(i18n("Edit EXIF Metadata")) +
(d->isReadOnly ? TQString(" - ") + i18n("(read only)") : TQString()));
diff --git a/kipi-plugins/metadataedit/iptceditdialog.cpp b/kipi-plugins/metadataedit/iptceditdialog.cpp
index a4beb35..4364322 100644
--- a/kipi-plugins/metadataedit/iptceditdialog.cpp
+++ b/kipi-plugins/metadataedit/iptceditdialog.cpp
@@ -304,7 +304,7 @@ void IPTCEditDialog::slotItemChanged()
setCaption(TQString("%1 (%2/%3) - %4")
.tqarg((*d->currItem).filename())
- .tqarg(d->urls.tqfindIndex(*(d->currItem))+1)
+ .tqarg(d->urls.findIndex(*(d->currItem))+1)
.tqarg(d->urls.count())
.tqarg(i18n("Edit IPTC Metadata")) +
(d->isReadOnly ? TQString(" - ") + i18n("(read only)") : TQString()));
diff --git a/kipi-plugins/mpegencoder/checkbinprog.cpp b/kipi-plugins/mpegencoder/checkbinprog.cpp
index 60ebf9d..59103a6 100644
--- a/kipi-plugins/mpegencoder/checkbinprog.cpp
+++ b/kipi-plugins/mpegencoder/checkbinprog.cpp
@@ -83,34 +83,34 @@ if (MjpegToolsPath.isEmpty())
// ImageMagick external programs.
if (montage.exists(TQString (ImageMagickPath+"/montage")) == FALSE)
- str = i18n("Cannot tqfind 'montage' binary program from ImageMagick package. Please install it.");
+ str = i18n("Cannot find 'montage' binary program from ImageMagick package. Please install it.");
if (composite.exists(TQString (ImageMagickPath+"/composite")) == FALSE)
- str = i18n("Cannot tqfind 'composite' binary program from ImageMagick package. Please install it.");
+ str = i18n("Cannot find 'composite' binary program from ImageMagick package. Please install it.");
if (convert.exists(TQString (ImageMagickPath+"/convert")) == FALSE)
- str = i18n("Cannot tqfind 'convert' binary program from ImageMagick package. Please install it.");
+ str = i18n("Cannot find 'convert' binary program from ImageMagick package. Please install it.");
if (identify.exists(TQString (ImageMagickPath+"/identify")) == FALSE)
- str = i18n("Cannot tqfind 'identify' binary program from ImageMagick package. Please install it.");
+ str = i18n("Cannot find 'identify' binary program from ImageMagick package. Please install it.");
// MjpegTools external programs.
if (ppmtoy4m.exists(TQString (MjpegToolsPath+"/ppmtoy4m")) == FALSE)
- str = i18n("Cannot tqfind 'ppmtoy4m' binary program from MjpegTools package. Please install it.");
+ str = i18n("Cannot find 'ppmtoy4m' binary program from MjpegTools package. Please install it.");
if (yuvscaler.exists(TQString (MjpegToolsPath+"/yuvscaler")) == FALSE)
- str = i18n("Cannot tqfind 'yuvscaler' binary program from MjpegTools package. Please install it.");
+ str = i18n("Cannot find 'yuvscaler' binary program from MjpegTools package. Please install it.");
if (mpeg2enc.exists(TQString (MjpegToolsPath+"/mpeg2enc")) == FALSE)
- str = i18n("Cannot tqfind 'mpeg2enc' binary program from MjpegTools package. Please install it.");
+ str = i18n("Cannot find 'mpeg2enc' binary program from MjpegTools package. Please install it.");
if ( mplex.exists(TQString (MjpegToolsPath+"/mplex")) == FALSE)
- str = i18n("Cannot tqfind 'mplex' binary program from MjpegTools package. Please install it.");
+ str = i18n("Cannot find 'mplex' binary program from MjpegTools package. Please install it.");
if (mp2enc.exists(TQString (MjpegToolsPath+"/mp2enc")) == FALSE)
{
- str = i18n("Cannot tqfind 'mp2enc' binary program from MjpegTools package. Please install it.\n"
+ str = i18n("Cannot find 'mp2enc' binary program from MjpegTools package. Please install it.\n"
"Audio capabilities will be disabled.");
ValRet = 2;
}
diff --git a/kipi-plugins/mpegencoder/images2mpg b/kipi-plugins/mpegencoder/images2mpg
index c720d2d..665590c 100755
--- a/kipi-plugins/mpegencoder/images2mpg
+++ b/kipi-plugins/mpegencoder/images2mpg
@@ -565,19 +565,19 @@ else
# check if programs are installed
if [ ! -e $MONTAGE_BIN ]; then
- echo -e "\nCan't tqfind $MONTAGE_BIN, please install it or check -I parameter"
+ echo -e "\nCan't find $MONTAGE_BIN, please install it or check -I parameter"
exit -1
fi
if [ ! -e $COMPOSITE_BIN ]; then
- echo -e "\nCan't tqfind $COMPOSITE_BIN, please install it or check -I parameter"
+ echo -e "\nCan't find $COMPOSITE_BIN, please install it or check -I parameter"
exit -1
fi
if [ ! -e $CONVERT_BIN ]; then
- echo -e "\nCan't tqfind $CONVERT_BIN, please install it or check -I parameter"
+ echo -e "\nCan't find $CONVERT_BIN, please install it or check -I parameter"
exit -1
fi
if [ ! -e $IDENTIFY_BIN ]; then
- echo -e "\nCan't tqfind $IDENTIFY_BIN, please install it or check -I parameter"
+ echo -e "\nCan't find $IDENTIFY_BIN, please install it or check -I parameter"
exit -1
fi
fi
@@ -602,31 +602,31 @@ else
fi
# check if programs are installed
if [ ! -e $PPMTOY4M_BIN ]; then
- echo -e "\nCan't tqfind $PPMTOY4M_BIN, please install it or check -M parameter"
+ echo -e "\nCan't find $PPMTOY4M_BIN, please install it or check -M parameter"
exit -1
fi
if [ ! -e $YUVSCALER_BIN ]; then
- echo -e "\nCan't tqfind $YUVSCALER_BIN, please install it or check -M parameter"
+ echo -e "\nCan't find $YUVSCALER_BIN, please install it or check -M parameter"
exit -1
fi
if [ ! -e $MPEG2ENC_BIN ]; then
- echo -e "\nCan't tqfind $MPEG2ENC_BIN, please install it or check -M parameter"
+ echo -e "\nCan't find $MPEG2ENC_BIN, please install it or check -M parameter"
exit -1
fi
if [ ! -e $MP2ENC_BIN ]; then
- echo -e "\nCan't tqfind $MP2ENC_BIN, please install it or check -M parameter"
+ echo -e "\nCan't find $MP2ENC_BIN, please install it or check -M parameter"
exit -1
fi
if [ ! -e $OGG_BIN ]; then
- echo -e "\nCan't tqfind $OGG_BIN, please install it or check -M parameter"
+ echo -e "\nCan't find $OGG_BIN, please install it or check -M parameter"
exit -1
fi
if [ ! -e $MP3_BIN ]; then
- echo -e "\nCan't tqfind $MP3_BIN, please install it or check -M parameter"
+ echo -e "\nCan't find $MP3_BIN, please install it or check -M parameter"
exit -1
fi
if [ ! -e $MPLEX_BIN ]; then
- echo -e "\nCan't tqfind $MPLEX_BIN, please install it or check -M parameter"
+ echo -e "\nCan't find $MPLEX_BIN, please install it or check -M parameter"
exit -1
fi
diff --git a/kipi-plugins/mpegencoder/kimg2mpg.cpp b/kipi-plugins/mpegencoder/kimg2mpg.cpp
index 129816d..03eb1ea 100644
--- a/kipi-plugins/mpegencoder/kimg2mpg.cpp
+++ b/kipi-plugins/mpegencoder/kimg2mpg.cpp
@@ -662,7 +662,7 @@ void KImg2mpgData::slotEncode( void )
if ( InputAudioFileName.isEmpty() == false )
{
- if ( InputAudioFileName.tqfindRev(".mp2", -1, false) == -1 )
+ if ( InputAudioFileName.findRev(".mp2", -1, false) == -1 )
{
*m_Proc << "-w" << InputAudioFileName; // Input WAV/OGG/MP3 audio file name.
m_CommandLine = m_CommandLine + " -w \"" + InputAudioFileName + "\"";
@@ -819,9 +819,9 @@ void KImg2mpgData::readStderr(KProcess *, char *buffer, int buflen)
m_DebugOuputMessages.append(BufferTmp.left(buflen));
- if (m_EncodeString.tqcontains("Images encoding (%) :"))
+ if (m_EncodeString.contains("Images encoding (%) :"))
{
- int pos1 = m_EncodeString.tqfind(':');
+ int pos1 = m_EncodeString.find(':');
if (pos1 != -1)
{
@@ -829,7 +829,7 @@ void KImg2mpgData::readStderr(KProcess *, char *buffer, int buflen)
m_progress->setValue(newstring.toUInt());
}
- int pos2 = m_EncodeString.tqfind('[');
+ int pos2 = m_EncodeString.find('[');
if (pos2 != -1)
{
@@ -853,16 +853,16 @@ void KImg2mpgData::readStderr(KProcess *, char *buffer, int buflen)
{
// Print on the GUI the actual 'images2mpg' process.
- if (m_EncodeString.tqcontains("Initialising..."))
+ if (m_EncodeString.contains("Initialising..."))
m_frame->setText(i18n("Initialising..."));
- if (m_EncodeString.tqcontains("Merging MPEG flux..."))
+ if (m_EncodeString.contains("Merging MPEG flux..."))
{
m_frame->setText(i18n("Merging MPEG flux..."));
m_progress->setValue(100);
}
- if (m_EncodeString.tqcontains("Encoding audio file..."))
+ if (m_EncodeString.contains("Encoding audio file..."))
{
m_frame->setText(i18n("Encoding audio file..."));
m_progress->setValue(100);
@@ -870,10 +870,10 @@ void KImg2mpgData::readStderr(KProcess *, char *buffer, int buflen)
// Or errors detections...
- if (m_EncodeString.tqcontains("cat:") ||
- m_EncodeString.tqcontains("ERROR:") ||
- m_EncodeString.tqcontains("Broken pipe") ||
- m_EncodeString.tqcontains("No such file or directory"))
+ if (m_EncodeString.contains("cat:") ||
+ m_EncodeString.contains("ERROR:") ||
+ m_EncodeString.contains("Broken pipe") ||
+ m_EncodeString.contains("No such file or directory"))
{
m_Abort = true;
diff --git a/kipi-plugins/picasawebexport/picasawebtalker.cpp b/kipi-plugins/picasawebexport/picasawebtalker.cpp
index bc9afd6..dd5b3c7 100644
--- a/kipi-plugins/picasawebexport/picasawebtalker.cpp
+++ b/kipi-plugins/picasawebexport/picasawebtalker.cpp
@@ -456,7 +456,7 @@ bool PicasawebTalker::addPhoto(const TQString& photoPath, FPhotoInfo& info,
TQString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
#endif
TQFileInfo fileInfo(photoPath);
- if (rawFilesExt.upper().tqcontains(fileInfo.extension(false).upper()))
+ if (rawFilesExt.upper().contains(fileInfo.extension(false).upper()))
KDcrawIface::KDcraw::loadDcrawPreview(image, photoPath);
else
image.load(photoPath);
@@ -680,7 +680,7 @@ void PicasawebTalker::parseResponseGetToken(const TQByteArray &data)
//if it is 403 handle the error mesg
//figure out the auth string from this response
- if (str.tqfind("Auth="))
+ if (str.find("Auth="))
{
TQStringList strList = TQStringList::split("Auth=", str);
m_token = strList[1];
@@ -743,7 +743,7 @@ void PicasawebTalker::parseResponseListAlbums(const TQByteArray &data)
// The node data is a URL of which album id is the string following the last /
// like <id>http://www.picasaweb.google.com/.../AlbumID<id>
TQString albumIdUrl = detailsNode.toElement().text();
- int index = albumIdUrl.tqfindRev("/");
+ int index = albumIdUrl.findRev("/");
int length = albumIdUrl.length();
TQString album_id = albumIdUrl.right(length - index - 1);
fps.id = album_id;
diff --git a/kipi-plugins/printwizard/frmprintwizard.cpp b/kipi-plugins/printwizard/frmprintwizard.cpp
index 2691bf2..1a430c3 100644
--- a/kipi-plugins/printwizard/frmprintwizard.cpp
+++ b/kipi-plugins/printwizard/frmprintwizard.cpp
@@ -543,7 +543,7 @@ TQString FrmPrintWizard::captionFormatter(TPhoto *photo, const TQString& format)
if (imageSize.isValid()) {
resolution = TQString( "%1x%2" ).tqarg( imageSize.width()).tqarg( imageSize.height());
}
- str.tqreplace("\\n", "\n");
+ str.replace("\\n", "\n");
// %f filename
// %c comment
@@ -553,15 +553,15 @@ TQString FrmPrintWizard::captionFormatter(TPhoto *photo, const TQString& format)
// %r resolution
// %a aperture
// %l focal length
- str.tqreplace("%f", fi.fileName());
- str.tqreplace("%c", photo->exiv2Iface()->getExifComment());
- str.tqreplace("%d", KGlobal::locale()->formatDateTime(photo->exiv2Iface()->getImageDateTime(),
+ str.replace("%f", fi.fileName());
+ str.replace("%c", photo->exiv2Iface()->getExifComment());
+ str.replace("%d", KGlobal::locale()->formatDateTime(photo->exiv2Iface()->getImageDateTime(),
false, false));
- str.tqreplace("%t", photo->exiv2Iface()->getExifTagString("Exif.Photo.ExposureTime"));
- str.tqreplace("%i", photo->exiv2Iface()->getExifTagString("Exif.Photo.ISOSpeedRatings"));
- str.tqreplace("%r", resolution);
- str.tqreplace("%a", photo->exiv2Iface()->getExifTagString("Exif.Photo.FNumber"));
- str.tqreplace("%l", photo->exiv2Iface()->getExifTagString("Exif.Photo.FocalLength"));
+ str.replace("%t", photo->exiv2Iface()->getExifTagString("Exif.Photo.ExposureTime"));
+ str.replace("%i", photo->exiv2Iface()->getExifTagString("Exif.Photo.ISOSpeedRatings"));
+ str.replace("%r", resolution);
+ str.replace("%a", photo->exiv2Iface()->getExifTagString("Exif.Photo.FNumber"));
+ str.replace("%l", photo->exiv2Iface()->getExifTagString("Exif.Photo.FocalLength"));
return str;
}
@@ -1330,7 +1330,7 @@ void FrmPrintWizard::loadSettings()
// photo size
TQString photoSize = config.readEntry("PhotoSize");
- TQListBoxItem *item = ListPhotoSizes->tqfindItem(photoSize);
+ TQListBoxItem *item = ListPhotoSizes->findItem(photoSize);
if (item)
ListPhotoSizes->setCurrentItem(item);
else
diff --git a/kipi-plugins/printwizard/tphoto.cpp b/kipi-plugins/printwizard/tphoto.cpp
index f0e766d..cdae0d1 100644
--- a/kipi-plugins/printwizard/tphoto.cpp
+++ b/kipi-plugins/printwizard/tphoto.cpp
@@ -112,7 +112,7 @@ TQImage TPhoto::loadPhoto()
TQString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
#endif
TQFileInfo fileInfo(filename.path());
- if (rawFilesExt.upper().tqcontains( fileInfo.extension(false).upper() ))
+ if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() ))
KDcrawIface::KDcraw::loadDcrawPreview(photo, filename.path());
else
photo.load(filename.path()); // PENDING(blackie) handle URL
diff --git a/kipi-plugins/rawconverter/batchdialog.cpp b/kipi-plugins/rawconverter/batchdialog.cpp
index 06b30cd..c0a61fe 100644
--- a/kipi-plugins/rawconverter/batchdialog.cpp
+++ b/kipi-plugins/rawconverter/batchdialog.cpp
@@ -392,7 +392,7 @@ void BatchDialog::addItems(const TQStringList& itemList)
it != itemList.end(); ++it)
{
TQFileInfo fi(*it);
- if (fi.exists() && !m_itemDict.tqfind(fi.fileName()))
+ if (fi.exists() && !m_itemDict.find(fi.fileName()))
{
RawItem *item = new RawItem;
item->directory = fi.dirPath();
@@ -497,7 +497,7 @@ void BatchDialog::slotConvertBlinkTimerDone()
void BatchDialog::processing(const TQString& file)
{
TQString filename = TQFileInfo(file).fileName();
- m_currentConvertItem = m_itemDict.tqfind(filename);
+ m_currentConvertItem = m_itemDict.find(filename);
if (m_currentConvertItem)
{
m_listView->setSelected(m_currentConvertItem->viewItem, true);
@@ -627,7 +627,7 @@ void BatchDialog::customEvent(TQCustomEvent *event)
case(IDENTIFY):
{
TQFileInfo fi(d->filePath);
- RawItem *rawItem = m_itemDict.tqfind(fi.fileName());
+ RawItem *rawItem = m_itemDict.find(fi.fileName());
if (rawItem)
{
if (!d->image.isNull())
diff --git a/kipi-plugins/rawconverter/iccjpeg.c b/kipi-plugins/rawconverter/iccjpeg.c
index dc57124..e74a98d 100644
--- a/kipi-plugins/rawconverter/iccjpeg.c
+++ b/kipi-plugins/rawconverter/iccjpeg.c
@@ -133,7 +133,7 @@ write_icc_profile (j_compress_ptr cinfo,
void
setup_read_icc_profile (j_decompress_ptr cinfo)
{
- /* Tell the library to keep any APP2 data it may tqfind */
+ /* Tell the library to keep any APP2 data it may find */
jpeg_save_markers(cinfo, ICC_MARKER, 0xFFFF);
}
diff --git a/kipi-plugins/rawconverter/plugin_rawconverter.cpp b/kipi-plugins/rawconverter/plugin_rawconverter.cpp
index 1135d93..18ec120 100644
--- a/kipi-plugins/rawconverter/plugin_rawconverter.cpp
+++ b/kipi-plugins/rawconverter/plugin_rawconverter.cpp
@@ -128,7 +128,7 @@ bool Plugin_RawConverter::isRAWFile(const TQString& filePath)
#endif
TQFileInfo fileInfo(filePath);
- if (rawFilesExt.upper().tqcontains( fileInfo.extension(false).upper() ))
+ if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() ))
return true;
return false;
diff --git a/kipi-plugins/rawconverter/rawdecodingiface.cpp b/kipi-plugins/rawconverter/rawdecodingiface.cpp
index 70aff48..2da4272 100644
--- a/kipi-plugins/rawconverter/rawdecodingiface.cpp
+++ b/kipi-plugins/rawconverter/rawdecodingiface.cpp
@@ -303,7 +303,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
}
TQString libpngver(PNG_HEADER_VERSION_STRING);
- libpngver.tqreplace('\n', ' ');
+ libpngver.replace('\n', ' ');
soft.append(TQString(" (%1)").tqarg(libpngver));
png_text text;
text.key = "Software";
@@ -383,7 +383,7 @@ bool RawDecodingIface::loadedFromDcraw(const TQString& filePath,
#endif
TQString libtiffver(TIFFLIB_VERSION_STR);
- libtiffver.tqreplace('\n', ' ');
+ libtiffver.replace('\n', ' ');
soft.append(TQString(" ( %1 )").tqarg(libtiffver));
TIFFSetField(tif, TIFFTAG_SOFTWARE, (const char*)soft.ascii());
diff --git a/kipi-plugins/simpleviewerexport/simpleviewerexport.cpp b/kipi-plugins/simpleviewerexport/simpleviewerexport.cpp
index d039f42..870cbe3 100644
--- a/kipi-plugins/simpleviewerexport/simpleviewerexport.cpp
+++ b/kipi-plugins/simpleviewerexport/simpleviewerexport.cpp
@@ -342,9 +342,9 @@ bool SimpleViewerExport::exportImages()
xmlDoc.appendChild( galleryElem );
galleryElem.setAttribute(TQString::tqfromLatin1("maxImageWidth"), m_configDlg->maxImageDimension());
galleryElem.setAttribute(TQString::tqfromLatin1("maxImageHeight"), m_configDlg->maxImageDimension());
- galleryElem.setAttribute(TQString::tqfromLatin1("textColor"), TQString(m_configDlg->textColor().name()).tqreplace("#", "0x"));
- galleryElem.setAttribute(TQString::tqfromLatin1("frameColor"), TQString(m_configDlg->frameColor().name()).tqreplace("#", "0x"));
- galleryElem.setAttribute(TQString::tqfromLatin1("bgColor"), TQString(m_configDlg->backgroundColor().name()).tqreplace("#", "0x"));
+ galleryElem.setAttribute(TQString::tqfromLatin1("textColor"), TQString(m_configDlg->textColor().name()).replace("#", "0x"));
+ galleryElem.setAttribute(TQString::tqfromLatin1("frameColor"), TQString(m_configDlg->frameColor().name()).replace("#", "0x"));
+ galleryElem.setAttribute(TQString::tqfromLatin1("bgColor"), TQString(m_configDlg->backgroundColor().name()).replace("#", "0x"));
galleryElem.setAttribute(TQString::tqfromLatin1("frameWidth"), m_configDlg->frameWidth());
galleryElem.setAttribute(TQString::tqfromLatin1("stagePadding"), m_configDlg->stagePadding());
galleryElem.setAttribute(TQString::tqfromLatin1("thumbnailColumns"), m_configDlg->thumbnailColumns());
@@ -385,7 +385,7 @@ bool SimpleViewerExport::exportImages()
#else
TQString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
#endif
- if (rawFilesExt.upper().tqcontains( fileInfo.extension(false).upper() ))
+ if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() ))
KDcrawIface::KDcraw::loadDcrawPreview(image, url.path());
else
image.load(url.path());
@@ -545,11 +545,11 @@ bool SimpleViewerExport::createIndex()
TQString indexTemplate = in.read();
infile.close();
- indexTemplate.tqreplace("{TITLE}", m_configDlg->title());
- indexTemplate.tqreplace("{COLOR}", m_configDlg->textColor().name());
- indexTemplate.tqreplace("{BGCOLOR}", m_configDlg->backgroundColor().name());
- indexTemplate.tqreplace("{HOSTURL}", m_hostURL);
- indexTemplate.tqreplace("{HOSTNAME}", m_hostName);
+ indexTemplate.replace("{TITLE}", m_configDlg->title());
+ indexTemplate.replace("{COLOR}", m_configDlg->textColor().name());
+ indexTemplate.replace("{BGCOLOR}", m_configDlg->backgroundColor().name());
+ indexTemplate.replace("{HOSTURL}", m_hostURL);
+ indexTemplate.replace("{HOSTNAME}", m_hostName);
TQFile outfile(m_tempDir->name() + "/index.html");
outfile.open(IO_WriteOnly);
diff --git a/kipi-plugins/slideshow/slideshowloader.cpp b/kipi-plugins/slideshow/slideshowloader.cpp
index 4b27b36..b470885 100644
--- a/kipi-plugins/slideshow/slideshowloader.cpp
+++ b/kipi-plugins/slideshow/slideshowloader.cpp
@@ -198,7 +198,7 @@ namespace KIPISlideShowPlugin
void SlideShowLoader::checkIsIn(int index)
{
m_threadLock->lock();
- if (m_loadingThreads->tqcontains(m_pathList[index].first))
+ if (m_loadingThreads->contains(m_pathList[index].first))
{
if ( (*m_loadingThreads)[m_pathList[index].first]->running() )
(*m_loadingThreads)[m_pathList[index].first]->wait();
diff --git a/kipi-plugins/sync/gallerywindow.cpp b/kipi-plugins/sync/gallerywindow.cpp
index 958ad6f..ebaf53e 100644
--- a/kipi-plugins/sync/gallerywindow.cpp
+++ b/kipi-plugins/sync/gallerywindow.cpp
@@ -285,7 +285,7 @@ void GalleryWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
}
else
{
- TQListViewItem* tqparent = m_albumDict.tqfind( album.parent_ref_num );
+ TQListViewItem* tqparent = m_albumDict.find( album.parent_ref_num );
if ( tqparent )
{
GAlbumViewItem* item = new GAlbumViewItem( tqparent, album.title,
@@ -316,7 +316,7 @@ void GalleryWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
if (lastSelectedID > 0)
{
- GAlbumViewItem* lastSelectedItem = m_albumDict.tqfind( lastSelectedID );
+ GAlbumViewItem* lastSelectedItem = m_albumDict.find( lastSelectedID );
if (lastSelectedItem)
{
m_albumView->setSelected( lastSelectedItem, true );
diff --git a/kipi-plugins/sync/sinkfactory.cpp b/kipi-plugins/sync/sinkfactory.cpp
index f3ebe28..3a528ee 100644
--- a/kipi-plugins/sync/sinkfactory.cpp
+++ b/kipi-plugins/sync/sinkfactory.cpp
@@ -27,7 +27,7 @@ SinkMap SinkFactory::mSinkProxies;
// Define the register method
bool SinkFactory::Register(TQString type, SinkProxy* pSinkProxy)
{
- if (mSinkProxies.tqcontains(type))
+ if (mSinkProxies.contains(type))
return false;
mSinkProxies[type] = pSinkProxy;
@@ -37,7 +37,7 @@ bool SinkFactory::Register(TQString type, SinkProxy* pSinkProxy)
// The main creation method
Sink* SinkFactory::Create(TQString type, unsigned int sinkId, TQString name, KConfig* pConfig, KWallet::Wallet* pWallet)
{
- if (!mSinkProxies.tqcontains(type))
+ if (!mSinkProxies.contains(type))
return NULL;
return (*(mSinkProxies[type]))(sinkId, name, pConfig, pWallet);
diff --git a/kipi-plugins/sync/sinks/gallery/gallerysink.cpp b/kipi-plugins/sync/sinks/gallery/gallerysink.cpp
index 9e60716..acfae60 100644
--- a/kipi-plugins/sync/sinks/gallery/gallerysink.cpp
+++ b/kipi-plugins/sync/sinks/gallery/gallerysink.cpp
@@ -514,9 +514,9 @@ void GallerySink::parseResponseListPhotos(const TQByteArray &data)
}
else
{
- // Boris the Gallery default URL tqcontains "=" char. So we will split the string only from the first "=" char
+ // Boris the Gallery default URL contains "=" char. So we will split the string only from the first "=" char
TQStringList strlist = TQStringList();
- strlist << line.left(line.tqfind('=')) << line.mid(line.tqfind('=')+1);
+ strlist << line.left(line.find('=')) << line.mid(line.find('=')+1);
if (strlist.count() >= 2)
{
TQString key = strlist[0];
@@ -545,7 +545,7 @@ void GallerySink::parseResponseListPhotos(const TQByteArray &data)
}
else if (key.startsWith("baseurl"))
{
- albumURL = value.tqreplace("\\","");
+ albumURL = value.replace("\\","");
}
}
}
diff --git a/kipi-plugins/sendimages/sendimages.cpp b/kipi-plugins/sendimages/sendimages.cpp
index b90e7d0..ed6f736 100644
--- a/kipi-plugins/sendimages/sendimages.cpp
+++ b/kipi-plugins/sendimages/sendimages.cpp
@@ -172,7 +172,7 @@ void SendImages::run()
}
else
{
- commentItem = ItemName.left(ItemName.tqfindRev('.'));
+ commentItem = ItemName.left(ItemName.findRev('.'));
qDebug("commentItem is empty");
}
@@ -183,12 +183,12 @@ void SendImages::run()
// Thunderbird does not like (). Replace them, BUG:131343
- TempFileName.tqreplace(TQChar('('), "_").tqreplace(TQChar(')'), "_");
+ TempFileName.replace(TQChar('('), "_").replace(TQChar(')'), "_");
// and these characters are better eliminated, too ;-)
- TempFileName.tqreplace(TQChar(','), "_").tqreplace(TQChar(' '), "_");
- TempFileName.tqreplace(TQChar(';'), "_").tqreplace(TQChar('%'), "_");
- TempFileName.tqreplace(TQChar('/'), "-").tqreplace(TQChar('?'), "");
- TempFileName.tqreplace(TQChar('"'), "");
+ TempFileName.replace(TQChar(','), "_").replace(TQChar(' '), "_");
+ TempFileName.replace(TQChar(';'), "_").replace(TQChar('%'), "_");
+ TempFileName.replace(TQChar('/'), "-").replace(TQChar('?'), "");
+ TempFileName.replace(TQChar('"'), "");
//If TempFileName already exists, add a number oder increase number
if (entry_already_exists(m_filesSendList,m_tmp + TempFileName))
{
@@ -216,7 +216,7 @@ void SendImages::run()
{
// Prepare resizing images.
//TQString imageNameFormat = TempFileName.tqreplace(TQChar('.'), "_") +
// extension(m_imageFormat);
qDebug( "Resizing %s-> '%s %s ' (%s ; %d )",imageName.ascii(),
@@ -799,7 +799,7 @@ bool SendImages::resizeImageProcess(const TQString &SourcePath, const TQString &
TQString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
#endif
TQFileInfo fileInfo(SourcePath);
- if (rawFilesExt.upper().tqcontains( fileInfo.extension(false).upper() ))
+ if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() ))
KDcrawIface::KDcraw::loadDcrawPreview(img, SourcePath);
else
img.load(SourcePath);
@@ -865,7 +865,7 @@ void SendImages::slotMozillaExited(KProcess*)
m_mailAgentProc->disconnect(TQT_SIGNAL(processExited(KProcess *)), this, TQT_SLOT(slotMozillaExited(KProcess*)));
qDebug("Number of elements in m_filesSendList=%d, and in m_filesSendList_copy=%d)",(int)m_filesSendList.size(),(int)m_filesSendList_copy.size());
- if ( m_mozillaStdErr.tqfind("No running window found") != -1 ) // No remote Mozilla | Netscape |
+ if ( m_mozillaStdErr.find("No running window found") != -1 ) // No remote Mozilla | Netscape |
{ // Thunderbird env. loaded !
m_mailAgentProc2 = new KProcess; // Init a new env.
@@ -216,7 +216,7 @@ void SendImages::run()
{
// Prepare resizing images.
- //TQString imageNameFormat = TempFileName.tqreplace(TQChar('.'), "_") +
+ //TQString imageNameFormat = TempFileName.replace(TQChar('.'), "_") +
// extension(m_imageFormat);
qDebug( "Resizing %s-> '%s %s ' (%s ; %d )",imageName.ascii(),